@@ -114,8 +114,9 @@ struct wcore_platform_vtbl {
         struct wcore_window*
         (*create)(struct wcore_platform *platform,
                   struct wcore_config *config,
-                  int width,
-                  int height);
+                  int32_t width,
+                  int32_t height,
+                  const intptr_t attrib_list[]);
         bool
         (*destroy)(struct wcore_window *window);
 
@@ -138,11 +139,13 @@ struct wcore_platform_vtbl {
 
 struct wcore_platform {
     const struct wcore_platform_vtbl *vtbl;
+    enum waffle_enum waffle_platform; // WAFFLE_PLATFORM_*
 };
 
 static inline bool
 wcore_platform_init(struct wcore_platform *self)
 {
+    (void) self;
     assert(self);
     return true;
 }
@@ -150,6 +153,7 @@ wcore_platform_init(struct wcore_platform *self)
 static inline bool
 wcore_platform_teardown(struct wcore_platform *self)
 {
+    (void) self;
     assert(self);
     return true;
 }
