@@ -41,8 +41,6 @@ static bool
 check_context_attrs(struct wegl_display *dpy,
                     const struct wcore_config_attrs *attrs)
 {
-    struct wcore_platform *plat = dpy->wcore.platform;
-
     if (attrs->context_forward_compatible) {
         assert(attrs->context_api == WAFFLE_CONTEXT_OPENGL);
         assert(wcore_config_attrs_version_ge(attrs, 30));
@@ -55,8 +53,35 @@ check_context_attrs(struct wegl_display *dpy,
         return false;
     }
 
+    if (attrs->context_robust && !dpy->EXT_create_context_robustness &&
+        dpy->major_version == 1 && dpy->minor_version < 5 &&
+        attrs->context_api != WAFFLE_CONTEXT_OPENGL) {
+        wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
+                     "EGL_EXT_create_context_robustness or EGL 1.5 is "
+                     "required in order to request a robust access context "
+                     "for OpenGL ES");
+        return false;
+    }
+
+    if (attrs->context_robust && !dpy->KHR_create_context &&
+        dpy->major_version == 1 && dpy->minor_version < 5 &&
+        attrs->context_api == WAFFLE_CONTEXT_OPENGL) {
+        wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
+                     "EGL_KHR_create_context or EGL 1.5 is required in order to "
+                     "request a robust access context for OpenGL");
+        return false;
+    }
+
     switch (attrs->context_api) {
         case WAFFLE_CONTEXT_OPENGL:
+            if (!(dpy->api_mask & WEGL_OPENGL_API)) {
+                wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
+                             "EGL 1.4 and eglQueryString(EGL_CLIENT_APIS) "
+                             "advertising \"OpenGL\" are required in order to "
+                             "request an OpenGL context.");
+                return false;
+            }
+
             if (!wcore_config_attrs_version_eq(attrs, 10) && !dpy->KHR_create_context) {
                 wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
                              "KHR_EXT_create_context is required in order to "
@@ -77,51 +102,29 @@ check_context_attrs(struct wegl_display *dpy,
                 return false;
             }
 
-            if (!plat->vtbl->dl_can_open(plat, WAFFLE_DL_OPENGL)) {
-                wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
-                             "failed to open the OpenGL library");
-                return false;
-            }
-
             return true;
 
         case WAFFLE_CONTEXT_OPENGL_ES1:
-            if (!plat->vtbl->dl_can_open(plat, WAFFLE_DL_OPENGL_ES1)) {
-                wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
-                             "failed to open the OpenGL ES1 library");
-                return false;
-            }
-
-            return true;
-
         case WAFFLE_CONTEXT_OPENGL_ES2:
-            if (!plat->vtbl->dl_can_open(plat, WAFFLE_DL_OPENGL_ES2)) {
+        case WAFFLE_CONTEXT_OPENGL_ES3:
+            if (!(dpy->api_mask & WEGL_OPENGL_ES_API)) {
                 wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
-                             "failed to open the OpenGL ES2 library");
+                             "eglQueryString(EGL_CLIENT_APIS) does not"
+                             "advertise OpenGL_ES.");
                 return false;
             }
-
-            return true;
-
-        case WAFFLE_CONTEXT_OPENGL_ES3:
-            if (!dpy->KHR_create_context) {
+            if (attrs->context_api == WAFFLE_CONTEXT_OPENGL_ES3 &&
+                !dpy->KHR_create_context) {
                 wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
                              "EGL_KHR_create_context is required to request "
                              "an OpenGL ES3 context");
                 return false;
             }
 
-            if (!plat->vtbl->dl_can_open(plat, WAFFLE_DL_OPENGL_ES3)) {
-                wcore_errorf(WAFFLE_ERROR_UNSUPPORTED_ON_PLATFORM,
-                             "failed to open the OpenGL ES3 library");
-                return false;
-            }
-
             return true;
 
         default:
-            wcore_error_internal("context_api has bad value %#x",
-                                 attrs->context_api);
+            assert(false);
             return false;
     }
 }
@@ -165,9 +168,10 @@ choose_real_config(struct wegl_display *dpy,
         EGL_RENDERABLE_TYPE,        31415926,
 
         // According to the EGL 1.4 spec Table 3.4, the default value of
-        // EGL_SURFACE_BIT is EGL_WINDOW_BIT.  Explicitly set the default here for
-        // the sake of self-documentation.
-        EGL_SURFACE_TYPE,           EGL_WINDOW_BIT,
+        // EGL_SURFACE_BIT is EGL_WINDOW_BIT.  We explicitly set the attribute
+        // here because not all Waffle platforms require EGL_WINDOW_BIT.
+        EGL_SURFACE_TYPE,           plat->egl_surface_type_mask,
+
         EGL_NONE,
     };
 
@@ -185,8 +189,7 @@ choose_real_config(struct wegl_display *dpy,
             attrib_list[renderable_index] = EGL_OPENGL_ES3_BIT_KHR;
             break;
         default:
-            wcore_error_internal("waffle_context_api has bad value %#x",
-                                 attrs->context_api);
+            assert(false);
             return NULL;
     }
 
@@ -211,10 +214,13 @@ wegl_config_choose(struct wcore_platform *wc_plat,
                    struct wcore_display *wc_dpy,
                    const struct wcore_config_attrs *attrs)
 {
+    struct wegl_platform *plat = wegl_platform(wc_plat);
     struct wegl_display *dpy = wegl_display(wc_dpy);
     struct wegl_config *config;
     bool ok;
 
+    (void) wc_plat;
+
     config = wcore_calloc(sizeof(*config));
     if (!config)
         return NULL;
@@ -230,6 +236,12 @@ wegl_config_choose(struct wcore_platform *wc_plat,
     if (!config->egl)
         goto fail;
 
+    ok = plat->eglGetConfigAttrib(dpy->egl, config->egl,
+                                  EGL_NATIVE_VISUAL_ID, &config->visual);
+
+    if (!ok)
+        goto fail;
+
     return &config->wcore;
 
 fail:
