@@ -63,6 +63,7 @@ glx_display_set_extensions(struct glx_display *self)
 
     self->ARB_create_context                     = waffle_is_extension_in_string(s, "GLX_ARB_create_context");
     self->ARB_create_context_profile             = waffle_is_extension_in_string(s, "GLX_ARB_create_context_profile");
+    self->ARB_create_context_robustness          = waffle_is_extension_in_string(s, "GLX_ARB_create_context_robustness");
     self->EXT_create_context_es_profile          = waffle_is_extension_in_string(s, "GLX_EXT_create_context_es_profile");
 
     // The GLX_EXT_create_context_es2_profile spec, version 4 2012/03/28,
@@ -117,26 +118,18 @@ glx_display_supports_context_api(struct wcore_display *wc_self,
                                  int32_t context_api)
 {
     struct glx_display *self = glx_display(wc_self);
-    struct glx_platform *plat = glx_platform(wc_self->platform);
 
     switch (context_api) {
         case WAFFLE_CONTEXT_OPENGL:
             return true;
         case WAFFLE_CONTEXT_OPENGL_ES1:
-            return self->EXT_create_context_es_profile
-                   && linux_platform_dl_can_open(plat->linux,
-                                                 WAFFLE_DL_OPENGL_ES1);
+            return self->EXT_create_context_es_profile;
         case WAFFLE_CONTEXT_OPENGL_ES2:
-            return self->EXT_create_context_es2_profile
-                   && linux_platform_dl_can_open(plat->linux,
-                                                 WAFFLE_DL_OPENGL_ES2);
+            return self->EXT_create_context_es2_profile;
         case WAFFLE_CONTEXT_OPENGL_ES3:
-            return self->EXT_create_context_es_profile
-                   && linux_platform_dl_can_open(plat->linux,
-                                                 WAFFLE_DL_OPENGL_ES3);
+            return self->EXT_create_context_es_profile;
         default:
-            wcore_error_internal("waffle_context_api has bad value %#x",
-                                 context_api);
+            assert(false);
             return false;
     }
 }
